Protocol Buffers Plus for Python
================================

|release level|

    Beautiful, idiomatic protocol buffers.

This is a wrapper around `protocol buffers`_. Protocol buffers is a
specification format for APIs, such as those inside Google.
This library provides protocol buffer message classes and objects that
largely behave like native Python types.

.. _protocol buffers: https://developers.google.com/protocol-buffers/


Disclaimer
----------

This is not an official Google product.


.. |release level| image:: https://img.shields.io/badge/release%20level-alpha-red.svg?style&#x3D;flat
  :target: https://cloud.google.com/terms/launch-stages
